@@ -118,7 +118,7 @@ impl Data {
 
 impl AsRef<[Transaction]> for Data {
     fn as_ref(&self) -> &[Transaction] {
-        self.txs.as_deref().unwrap_or_else(|| &[])
+        self.txs.as_deref().unwrap_or(&[])
     }
 }
 
