@@ -1,11 +1,12 @@
 //! Define traits and instances for dealing with trust thresholds.
 
-use std::fmt::{self, Debug, Display};
+use core::fmt::{self, Debug, Display};
 
 use crate::error::Error;
-use crate::{serializers, Kind};
+use crate::prelude::*;
+use crate::serializers;
+use core::convert::TryFrom;
 use serde::{de::DeserializeOwned, Deserialize, Serialize};
-use std::convert::TryFrom;
 
 /// TrustThreshold defines how much of the total voting power of a known
 /// and trusted validator set is sufficient for a commit to be
@@ -53,13 +54,13 @@ impl TrustThresholdFraction {
     /// In any other case we return an error.
     pub fn new(numerator: u64, denominator: u64) -> Result<Self, Error> {
         if numerator >= denominator {
-            return Err(Kind::TrustThresholdTooLarge.into());
+            return Err(Error::trust_threshold_too_large());
         }
         if denominator == 0 {
-            return Err(Kind::UndefinedTrustThreshold.into());
+            return Err(Error::undefined_trust_threshold());
         }
         if 3 * numerator < denominator {
-            return Err(Kind::TrustThresholdTooSmall.into());
+            return Err(Error::trust_threshold_too_small());
         }
         Ok(Self {
             numerator,
